.. :changelog:

History
-------

0.3.0 (2020-11-03)
------------------

* Reflect all round updates on API, License and Docs.


0.2.5 (2020-11-02)
------------------

* Updated API Base URLs


0.2.4 (2016-09-15)
------------------

* Added request_money API (See `Request Money API <http://developer.lipisha.com/index.php/app/launch/api_request_money>`)


0.2.3 (2016-04-20)
------------------

* Encoding bugfix (See `Issue 1 <https://github.com/lipisha/lipisha-python-sdk/issues/1>`).


0.2.1 /0.2.2 (2015-08-14)
-------------------------

* Documentation updates
* PYPI releases


0.2.0 (2015-08-14)
------------------

* Bytes handling fixes (Python3.3/Python3.4)
* Sandbox testing
* Implemented new api endpoints
    * Card authorization and settlement
    * Transactions listing
    * Customers listing
    * Settlement accounts setup
    * Transaction acccounts setup
* Improved documentation


0.1.0 (2015-08-12)
---------------------

* First release on PyPI.
